==> myst-parser_0.16.1.orig.tar.gz: MyST-Parser-0.16.1/tests/test_renderers/fixtures/docutil_roles.md <==
--------------------------------
abbreviation (`docutils.parsers.rst.roles.GenericRole`):
.
{abbreviation}`a`
.
<document source="notset">
    <paragraph>
        <abbreviation>
            a
.

--------------------------------
acronym (`docutils.parsers.rst.roles.GenericRole`):
.
{acronym}`a`
.
<document source="notset">
    <paragraph>
        <acronym>
            a
.

--------------------------------
emphasis (`docutils.parsers.rst.roles.GenericRole`):
.
{emphasis}`a`
.
<document source="notset">
    <paragraph>
        <emphasis>
            a
.

--------------------------------
literal (`docutils.parsers.rst.roles.GenericRole`):
.
{literal}`a`
.
<document source="notset">
    <paragraph>
        <literal>
            a
.

--------------------------------
strong (`docutils.parsers.rst.roles.GenericRole`):
.
{strong}`a`
.
<document source="notset">
    <paragraph>
        <strong>
            a
.

--------------------------------
subscript (`docutils.parsers.rst.roles.GenericRole`):
.
{subscript}`a`
.
<document source="notset">
    <paragraph>
        <subscript>
            a
.

--------------------------------
superscript (`docutils.parsers.rst.roles.GenericRole`):
.
{superscript}`a`
.
<document source="notset">
    <paragraph>
        <superscript>
            a
.

--------------------------------
title-reference (`docutils.parsers.rst.roles.GenericRole`):
.
{title-reference}`t`
.
<document source="notset">
    <paragraph>
        <title_reference>
            t
.

--------------------------------
pep-reference (`docutils.parsers.rst.roles.pep_reference_role`):
.
{pep-reference}`0`
.
<document source="notset">
    <paragraph>
        <reference refuri="http://www.python.org/dev/peps/pep-0000">
            PEP 0
.

--------------------------------
rfc-reference (`docutils.parsers.rst.roles.rfc_reference_role`):
.
{rfc-reference}`1`
.
<document source="notset">
    <paragraph>
        <reference refuri="http://tools.ietf.org/html/rfc1.html">
            RFC 1
.

--------------------------------
code (`docutils.parsers.rst.roles.code_role`):
.
{code}`a`
.
<document source="notset">
    <paragraph>
        <literal classes="code">
            a
.

--------------------------------
math (`docutils.parsers.rst.roles.math_role`):
.
{math}`a`
.
<document source="notset">
    <paragraph>
        <math>
            a
.

==> myst-parser_0.18.1.orig.tar.gz: MyST-Parser-0.18.1/tests/test_renderers/fixtures/docutil_roles.md <==
--------------------------------
[abbreviation] (`docutils.parsers.rst.roles.GenericRole`):
.
{abbreviation}`a`
.
<document source="notset">
    <paragraph>
        <abbreviation>
            a
.

--------------------------------
[acronym] (`docutils.parsers.rst.roles.GenericRole`):
.
{acronym}`a`
.
<document source="notset">
    <paragraph>
        <acronym>
            a
.

--------------------------------
[emphasis] (`docutils.parsers.rst.roles.GenericRole`):
.
{emphasis}`a`
.
<document source="notset">
    <paragraph>
        <emphasis>
            a
.

--------------------------------
[literal] (`docutils.parsers.rst.roles.GenericRole`):
.
{literal}`a`
.
<document source="notset">
    <paragraph>
        <literal>
            a
.

--------------------------------
[strong] (`docutils.parsers.rst.roles.GenericRole`):
.
{strong}`a`
.
<document source="notset">
    <paragraph>
        <strong>
            a
.

--------------------------------
[subscript] (`docutils.parsers.rst.roles.GenericRole`):
.
{subscript}`a`
.
<document source="notset">
    <paragraph>
        <subscript>
            a
.

--------------------------------
[superscript] (`docutils.parsers.rst.roles.GenericRole`):
.
{superscript}`a`
.
<document source="notset">
    <paragraph>
        <superscript>
            a
.

--------------------------------
[title-reference] (`docutils.parsers.rst.roles.GenericRole`):
.
{title-reference}`t`
.
<document source="notset">
    <paragraph>
        <title_reference>
            t
.

--------------------------------
[pep-reference] (`docutils.parsers.rst.roles.pep_reference_role`):
.
{pep-reference}`0`
.
<document source="notset">
    <paragraph>
        <reference refuri="https://peps.python.org/pep-0000">
            PEP 0
.

--------------------------------
[rfc-reference] (`docutils.parsers.rst.roles.rfc_reference_role`):
.
{rfc-reference}`1`
.
<document source="notset">
    <paragraph>
        <reference refuri="https://tools.ietf.org/html/rfc1.html">
            RFC 1
.

--------------------------------
[code] (`docutils.parsers.rst.roles.code_role`):
.
{code}`a`
.
<document source="notset">
    <paragraph>
        <literal classes="code">
            a
.

--------------------------------
[math] (`docutils.parsers.rst.roles.math_role`):
.
{math}`a`
.
<document source="notset">
    <paragraph>
        <math>
            a
.
